@@ -1,8 +1,9 @@
 # Ultralytics 🚀 AGPL-3.0 License - https://ultralytics.com/license
 
+from __future__ import annotations
+
 from abc import abstractmethod
 from pathlib import Path
-from typing import List, Union
 
 import torch
 import torch.nn as nn
@@ -91,7 +92,7 @@ class CLIP(TextModel):
         self.device = device
         self.eval()
 
-    def tokenize(self, texts: Union[str, List[str]]) -> torch.Tensor:
+    def tokenize(self, texts: str | list[str]) -> torch.Tensor:
         """
         Convert input texts to CLIP tokens.
 
@@ -135,7 +136,7 @@ class CLIP(TextModel):
         return txt_feats
 
     @smart_inference_mode()
-    def encode_image(self, image: Union[Image.Image, torch.Tensor], dtype: torch.dtype = torch.float32) -> torch.Tensor:
+    def encode_image(self, image: Image.Image | torch.Tensor, dtype: torch.dtype = torch.float32) -> torch.Tensor:
         """
         Encode preprocessed images into normalized feature vectors.
 
@@ -234,7 +235,7 @@ class MobileCLIP(TextModel):
         self.device = device
         self.eval()
 
-    def tokenize(self, texts: List[str]) -> torch.Tensor:
+    def tokenize(self, texts: list[str]) -> torch.Tensor:
         """
         Convert input texts to MobileCLIP tokens.
 
@@ -319,7 +320,7 @@ class MobileCLIPTS(TextModel):
         self.tokenizer = clip.clip.tokenize
         self.device = device
 
-    def tokenize(self, texts: List[str]) -> torch.Tensor:
+    def tokenize(self, texts: list[str]) -> torch.Tensor:
         """
         Convert input texts to MobileCLIP tokens.
 
