@@ -1,9 +1,11 @@
 # Ultralytics 🚀 AGPL-3.0 License - https://ultralytics.com/license
 
+from __future__ import annotations
+
 import math
 from collections import Counter, defaultdict
 from functools import lru_cache
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any
 
 import cv2
 import numpy as np
@@ -135,7 +137,7 @@ class BaseSolution:
             ops.Profile(device=self.device),  # solution
         )
 
-    def adjust_box_label(self, cls: int, conf: float, track_id: Optional[int] = None) -> Optional[str]:
+    def adjust_box_label(self, cls: int, conf: float, track_id: int | None = None) -> str | None:
         """
         Generate a formatted label for a bounding box.
 
@@ -302,8 +304,8 @@ class SolutionAnnotator(Annotator):
     def __init__(
         self,
         im: np.ndarray,
-        line_width: Optional[int] = None,
-        font_size: Optional[int] = None,
+        line_width: int | None = None,
+        font_size: int | None = None,
         font: str = "Arial.ttf",
         pil: bool = False,
         example: str = "abc",
@@ -323,8 +325,8 @@ class SolutionAnnotator(Annotator):
 
     def draw_region(
         self,
-        reg_pts: Optional[List[Tuple[int, int]]] = None,
-        color: Tuple[int, int, int] = (0, 255, 0),
+        reg_pts: list[tuple[int, int]] | None = None,
+        color: tuple[int, int, int] = (0, 255, 0),
         thickness: int = 5,
     ):
         """
@@ -344,9 +346,9 @@ class SolutionAnnotator(Annotator):
     def queue_counts_display(
         self,
         label: str,
-        points: Optional[List[Tuple[int, int]]] = None,
-        region_color: Tuple[int, int, int] = (255, 255, 255),
-        txt_color: Tuple[int, int, int] = (0, 0, 0),
+        points: list[tuple[int, int]] | None = None,
+        region_color: tuple[int, int, int] = (255, 255, 255),
+        txt_color: tuple[int, int, int] = (0, 0, 0),
     ):
         """
         Display queue counts on an image centered at the points with customizable font size and colors.
@@ -390,9 +392,9 @@ class SolutionAnnotator(Annotator):
     def display_analytics(
         self,
         im0: np.ndarray,
-        text: Dict[str, Any],
-        txt_color: Tuple[int, int, int],
-        bg_color: Tuple[int, int, int],
+        text: dict[str, Any],
+        txt_color: tuple[int, int, int],
+        bg_color: tuple[int, int, int],
         margin: int,
     ):
         """
@@ -425,7 +427,7 @@ class SolutionAnnotator(Annotator):
 
     @staticmethod
     @lru_cache(maxsize=256)
-    def estimate_pose_angle(a: List[float], b: List[float], c: List[float]) -> float:
+    def estimate_pose_angle(a: list[float], b: list[float], c: list[float]) -> float:
         """
         Calculate the angle between three points for workout monitoring.
 
@@ -443,8 +445,8 @@ class SolutionAnnotator(Annotator):
 
     def draw_specific_kpts(
         self,
-        keypoints: List[List[float]],
-        indices: Optional[List[int]] = None,
+        keypoints: list[list[float]],
+        indices: list[int] | None = None,
         radius: int = 2,
         conf_thresh: float = 0.25,
     ) -> np.ndarray:
@@ -480,9 +482,9 @@ class SolutionAnnotator(Annotator):
     def plot_workout_information(
         self,
         display_text: str,
-        position: Tuple[int, int],
-        color: Tuple[int, int, int] = (104, 31, 17),
-        txt_color: Tuple[int, int, int] = (255, 255, 255),
+        position: tuple[int, int],
+        color: tuple[int, int, int] = (104, 31, 17),
+        txt_color: tuple[int, int, int] = (255, 255, 255),
     ) -> int:
         """
         Draw workout text with a background on the image.
@@ -516,9 +518,9 @@ class SolutionAnnotator(Annotator):
         angle_text: str,
         count_text: str,
         stage_text: str,
-        center_kpt: List[int],
-        color: Tuple[int, int, int] = (104, 31, 17),
-        txt_color: Tuple[int, int, int] = (255, 255, 255),
+        center_kpt: list[int],
+        color: tuple[int, int, int] = (104, 31, 17),
+        txt_color: tuple[int, int, int] = (255, 255, 255),
     ):
         """
         Plot the pose angle, count value, and step stage for workout monitoring.
@@ -548,9 +550,9 @@ class SolutionAnnotator(Annotator):
     def plot_distance_and_line(
         self,
         pixels_distance: float,
-        centroids: List[Tuple[int, int]],
-        line_color: Tuple[int, int, int] = (104, 31, 17),
-        centroid_color: Tuple[int, int, int] = (255, 0, 255),
+        centroids: list[tuple[int, int]],
+        line_color: tuple[int, int, int] = (104, 31, 17),
+        centroid_color: tuple[int, int, int] = (255, 0, 255),
     ):
         """
         Plot the distance and line between two centroids on the frame.
@@ -589,8 +591,8 @@ class SolutionAnnotator(Annotator):
         self,
         im0: np.ndarray,
         text: str,
-        txt_color: Tuple[int, int, int],
-        bg_color: Tuple[int, int, int],
+        txt_color: tuple[int, int, int],
+        bg_color: tuple[int, int, int],
         x_center: float,
         y_center: float,
         margin: int,
@@ -638,9 +640,9 @@ class SolutionAnnotator(Annotator):
         self,
         line_x: int = 0,
         line_y: int = 0,
-        label: Optional[str] = None,
-        color: Tuple[int, int, int] = (221, 0, 186),
-        txt_color: Tuple[int, int, int] = (255, 255, 255),
+        label: str | None = None,
+        color: tuple[int, int, int] = (221, 0, 186),
+        txt_color: tuple[int, int, int] = (255, 255, 255),
     ):
         """
         Draw a sweep annotation line and an optional label.
@@ -677,10 +679,10 @@ class SolutionAnnotator(Annotator):
 
     def visioneye(
         self,
-        box: List[float],
-        center_point: Tuple[int, int],
-        color: Tuple[int, int, int] = (235, 219, 11),
-        pin_color: Tuple[int, int, int] = (255, 0, 255),
+        box: list[float],
+        center_point: tuple[int, int],
+        color: tuple[int, int, int] = (235, 219, 11),
+        pin_color: tuple[int, int, int] = (255, 0, 255),
     ):
         """
         Perform pinpoint human-vision eye mapping and plotting.
@@ -698,10 +700,10 @@ class SolutionAnnotator(Annotator):
 
     def adaptive_label(
         self,
-        box: Tuple[float, float, float, float],
+        box: tuple[float, float, float, float],
         label: str = "",
-        color: Tuple[int, int, int] = (128, 128, 128),
-        txt_color: Tuple[int, int, int] = (255, 255, 255),
+        color: tuple[int, int, int] = (128, 128, 128),
+        txt_color: tuple[int, int, int] = (255, 255, 255),
         shape: str = "rect",
         margin: int = 5,
     ):
