@@ -1,6 +1,8 @@
 # Ultralytics 🚀 AGPL-3.0 License - https://ultralytics.com/license
 
-from typing import Any, List, Optional, Tuple
+from __future__ import annotations
+
+from typing import Any
 
 import numpy as np
 
@@ -51,7 +53,7 @@ class STrack(BaseTrack):
 
     shared_kalman = KalmanFilterXYAH()
 
-    def __init__(self, xywh: List[float], score: float, cls: Any):
+    def __init__(self, xywh: list[float], score: float, cls: Any):
         """
         Initialize a new STrack instance.
 
@@ -89,7 +91,7 @@ class STrack(BaseTrack):
         self.mean, self.covariance = self.kalman_filter.predict(mean_state, self.covariance)
 
     @staticmethod
-    def multi_predict(stracks: List["STrack"]):
+    def multi_predict(stracks: list[STrack]):
         """Perform multi-object predictive tracking using Kalman filter for the provided list of STrack instances."""
         if len(stracks) <= 0:
             return
@@ -104,9 +106,9 @@ class STrack(BaseTrack):
             stracks[i].covariance = cov
 
     @staticmethod
-    def multi_gmc(stracks: List["STrack"], H: np.ndarray = np.eye(2, 3)):
+    def multi_gmc(stracks: list[STrack], H: np.ndarray = np.eye(2, 3)):
         """Update state tracks positions and covariances using a homography matrix for multiple tracks."""
-        if len(stracks) > 0:
+        if stracks:
             multi_mean = np.asarray([st.mean.copy() for st in stracks])
             multi_covariance = np.asarray([st.covariance for st in stracks])
 
@@ -135,7 +137,7 @@ class STrack(BaseTrack):
         self.frame_id = frame_id
         self.start_frame = frame_id
 
-    def re_activate(self, new_track: "STrack", frame_id: int, new_id: bool = False):
+    def re_activate(self, new_track: STrack, frame_id: int, new_id: bool = False):
         """Reactivate a previously lost track using new detection data and update its state and attributes."""
         self.mean, self.covariance = self.kalman_filter.update(
             self.mean, self.covariance, self.convert_coords(new_track.tlwh)
@@ -151,7 +153,7 @@ class STrack(BaseTrack):
         self.angle = new_track.angle
         self.idx = new_track.idx
 
-    def update(self, new_track: "STrack", frame_id: int):
+    def update(self, new_track: STrack, frame_id: int):
         """
         Update the state of a matched track.
 
@@ -225,7 +227,7 @@ class STrack(BaseTrack):
         return np.concatenate([self.xywh, self.angle[None]])
 
     @property
-    def result(self) -> List[float]:
+    def result(self) -> list[float]:
         """Get the current tracking results in the appropriate bounding box format."""
         coords = self.xyxy if self.angle is None else self.xywha
         return coords.tolist() + [self.track_id, self.score, self.cls, self.idx]
@@ -294,7 +296,7 @@ class BYTETracker:
         self.kalman_filter = self.get_kalmanfilter()
         self.reset_id()
 
-    def update(self, results, img: Optional[np.ndarray] = None, feats: Optional[np.ndarray] = None) -> np.ndarray:
+    def update(self, results, img: np.ndarray | None = None, feats: np.ndarray | None = None) -> np.ndarray:
         """Update the tracker with new detections and return the current list of tracked objects."""
         self.frame_id += 1
         activated_stracks = []
@@ -411,7 +413,7 @@ class BYTETracker:
         """Return a Kalman filter object for tracking bounding boxes using KalmanFilterXYAH."""
         return KalmanFilterXYAH()
 
-    def init_track(self, results, img: Optional[np.ndarray] = None) -> List[STrack]:
+    def init_track(self, results, img: np.ndarray | None = None) -> list[STrack]:
         """Initialize object tracking with given detections, scores, and class labels using the STrack algorithm."""
         if len(results) == 0:
             return []
@@ -419,14 +421,14 @@ class BYTETracker:
         bboxes = np.concatenate([bboxes, np.arange(len(bboxes)).reshape(-1, 1)], axis=-1)
         return [STrack(xywh, s, c) for (xywh, s, c) in zip(bboxes, results.conf, results.cls)]
 
-    def get_dists(self, tracks: List[STrack], detections: List[STrack]) -> np.ndarray:
+    def get_dists(self, tracks: list[STrack], detections: list[STrack]) -> np.ndarray:
         """Calculate the distance between tracks and detections using IoU and optionally fuse scores."""
         dists = matching.iou_distance(tracks, detections)
         if self.args.fuse_score:
             dists = matching.fuse_score(dists, detections)
         return dists
 
-    def multi_predict(self, tracks: List[STrack]):
+    def multi_predict(self, tracks: list[STrack]):
         """Predict the next states for multiple tracks using Kalman filter."""
         STrack.multi_predict(tracks)
 
@@ -445,7 +447,7 @@ class BYTETracker:
         self.reset_id()
 
     @staticmethod
-    def joint_stracks(tlista: List[STrack], tlistb: List[STrack]) -> List[STrack]:
+    def joint_stracks(tlista: list[STrack], tlistb: list[STrack]) -> list[STrack]:
         """Combine two lists of STrack objects into a single list, ensuring no duplicates based on track IDs."""
         exists = {}
         res = []
@@ -460,13 +462,13 @@ class BYTETracker:
         return res
 
     @staticmethod
-    def sub_stracks(tlista: List[STrack], tlistb: List[STrack]) -> List[STrack]:
+    def sub_stracks(tlista: list[STrack], tlistb: list[STrack]) -> list[STrack]:
         """Filter out the stracks present in the second list from the first list."""
         track_ids_b = {t.track_id for t in tlistb}
         return [t for t in tlista if t.track_id not in track_ids_b]
 
     @staticmethod
-    def remove_duplicate_stracks(stracksa: List[STrack], stracksb: List[STrack]) -> Tuple[List[STrack], List[STrack]]:
+    def remove_duplicate_stracks(stracksa: list[STrack], stracksb: list[STrack]) -> tuple[list[STrack], list[STrack]]:
         """Remove duplicate stracks from two lists based on Intersection over Union (IoU) distance."""
         pdist = matching.iou_distance(stracksa, stracksb)
         pairs = np.where(pdist < 0.15)
