@@ -1,7 +1,8 @@
 # Ultralytics 🚀 AGPL-3.0 License - https://ultralytics.com/license
 
+from __future__ import annotations
+
 import copy
-from typing import List, Optional
 
 import cv2
 import numpy as np
@@ -89,7 +90,7 @@ class GMC:
         self.prevDescriptors = None
         self.initializedFirstFrame = False
 
-    def apply(self, raw_frame: np.ndarray, detections: Optional[List] = None) -> np.ndarray:
+    def apply(self, raw_frame: np.ndarray, detections: list | None = None) -> np.ndarray:
         """
         Apply object detection on a raw frame using the specified method.
 
@@ -156,7 +157,7 @@ class GMC:
 
         return H
 
-    def apply_features(self, raw_frame: np.ndarray, detections: Optional[List] = None) -> np.ndarray:
+    def apply_features(self, raw_frame: np.ndarray, detections: list | None = None) -> np.ndarray:
         """
         Apply feature-based methods like ORB or SIFT to a raw frame.
 
